@@ -204,7 +204,7 @@ void print_separator(const char *separator);
 char *color(const char *colorstr);
 char *endcolor() __attribute__((pure));
 void reset_cursor(void);
-void maybe_escape_markup(char *text, char **buffer);
+void maybe_escape_markup(char *text, char *buffer, size_t size);
 
 char *rtrim(const char *s);
 char *ltrim(const char *s);
@@ -271,6 +271,7 @@ typedef struct {
     const char *status_bat;
     const char *status_unk;
     const char *status_full;
+    const char *status_idle;
     int low_threshold;
     char *threshold_type;
     bool last_full_capacity;
