@@ -68,7 +68,7 @@
 
 #include "i3status.h"
 
-#define STRING_SIZE 30
+#define STRING_SIZE 60
 
 #define WIRELESS_INFO_FLAG_HAS_ESSID (1 << 0)
 #define WIRELESS_INFO_FLAG_HAS_QUALITY (1 << 1)
@@ -93,13 +93,13 @@ typedef struct {
     int signal_level_max;
     int noise_level;
     int noise_level_max;
-    int bitrate;
+    long int bitrate;
     double frequency;
 } wireless_info_t;
 
 #if defined(__linux__) || defined(__FreeBSD__)
 // Like iw_print_bitrate, but without the dependency on libiw.
-static void print_bitrate(char *buffer, int buflen, int bitrate, const char *format_bitrate) {
+static void print_bitrate(char *buffer, int buflen, long int bitrate, const char *format_bitrate) {
     const int kilo = 1e3;
     const int mega = 1e6;
     const int giga = 1e9;
@@ -191,7 +191,7 @@ static int gwi_sta_cb(struct nl_msg *msg, void *data) {
 
     // NL80211_RATE_INFO_BITRATE is specified in units of 100 kbit/s, but iw
     // used to specify bit/s, so we convert to use the same code path.
-    info->bitrate = (int)nla_get_u16(rinfo[NL80211_RATE_INFO_BITRATE]) * 100 * 1000;
+    info->bitrate = (long int)nla_get_u16(rinfo[NL80211_RATE_INFO_BITRATE]) * 100 * 1000;
 
     if (sinfo[NL80211_STA_INFO_SIGNAL] != NULL) {
         info->flags |= WIRELESS_INFO_FLAG_HAS_SIGNAL;
@@ -402,9 +402,9 @@ error1:
     close(s);
     if (na.i_len >= sizeof(u.req)) {
         /*
-	 * Just use the first BSSID returned even if there are
-	 * multiple APs sharing the same BSSID.
-	 */
+         * Just use the first BSSID returned even if there are
+         * multiple APs sharing the same BSSID.
+         */
         info->signal_level = u.req.info[0].isi_rssi / 2 +
                              u.req.info[0].isi_noise;
         info->flags |= WIRELESS_INFO_FLAG_HAS_SIGNAL;
@@ -412,7 +412,7 @@ error1:
         info->flags |= WIRELESS_INFO_FLAG_HAS_NOISE;
         // isi_txmbps is specified in units of 500 Kbit/s
         // Convert them to bit/s
-        info->bitrate = u.req.info[0].isi_txmbps * 500 * 1000;
+        info->bitrate = (long int)u.req.info[0].isi_txmbps * 500 * 1000;
     }
 
     return 1;
@@ -469,9 +469,21 @@ error1:
 
             if (ioctl(s, SIOCG80211NODE, &nr) == 0 && nr.nr_rssi) {
                 info->signal_level = nr.nr_rssi;
-                if (nr.nr_max_rssi)
+                if (nr.nr_max_rssi) {
                     info->signal_level_max = nr.nr_max_rssi;
+                    info->quality = IEEE80211_NODEREQ_RSSI(&nr);
+                } else {
+                    if (info->signal_level <= -100)
+                        info->quality = 0;
+                    else if (info->signal_level > -50)
+                        info->quality = 100;
+                    else
+                        info->quality = abs(2 * (info->signal_level + 100));
+                }
+                info->quality_max = 100;
+                info->quality_average = 50;
 
+                info->flags |= WIRELESS_INFO_FLAG_HAS_QUALITY;
                 info->flags |= WIRELESS_INFO_FLAG_HAS_SIGNAL;
             }
         }
@@ -511,7 +523,7 @@ void print_wireless_info(wireless_info_ctx_t *ctx) {
     /*
      * Removing '%' and following characters from IPv6 since the interface identifier is redundant,
      * as the output already includes the interface name.
-    */
+     */
     if (ipv6_address != NULL) {
         char *prct_ptr = strstr(ipv6_address, "%");
         if (prct_ptr != NULL) {
@@ -589,10 +601,9 @@ void print_wireless_info(wireless_info_ctx_t *ctx) {
         snprintf(string_noise, STRING_SIZE, "?");
     }
 
-    char *tmp = string_essid;
 #ifdef IW_ESSID_MAX_SIZE
     if (info.flags & WIRELESS_INFO_FLAG_HAS_ESSID)
-        maybe_escape_markup(info.essid, &tmp);
+        maybe_escape_markup(info.essid, string_essid, STRING_SIZE);
     else
 #endif
         snprintf(string_essid, STRING_SIZE, "?");
